# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/parameters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/service/parameters.proto\x12\x10prodvana.service\x1a\'prodvana/common_config/parameters.proto\"w\n PerReleaseChannelParameterValues\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\x12:\n\nparameters\x18\x02 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\"\xa5\x01\n\x16ServiceParameterValues\x12:\n\nparameters\x18\x01 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x12O\n\x13per_release_channel\x18\x02 \x03(\x0b\x32\x32.prodvana.service.PerReleaseChannelParameterValuesBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.service.parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _globals['_PERRELEASECHANNELPARAMETERVALUES']._serialized_start=96
  _globals['_PERRELEASECHANNELPARAMETERVALUES']._serialized_end=215
  _globals['_SERVICEPARAMETERVALUES']._serialized_start=218
  _globals['_SERVICEPARAMETERVALUES']._serialized_end=383
# @@protoc_insertion_point(module_scope)
