# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/events/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.events import types_pb2 as prodvana_dot_events_dot_types__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprodvana/events/events.proto\x12\x0fprodvana.events\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bprodvana/events/types.proto\x1a&prodvana/version/source_metadata.proto\"\xd7\x02\n\x05\x45vent\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x04type\x18\x02 \x01(\x0e\x32\x1a.prodvana.events.EventType\x12\r\n\x05title\x18\x03 \x01(\t\x12.\n\x07\x64\x65tails\x18\x04 \x01(\x0b\x32\x1d.prodvana.events.EventDetails\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x0frelated_objects\x18\x06 \x01(\x0b\x32\x1f.prodvana.events.RelatedObjects\x12(\n\x06source\x18\x08 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\t \x01(\x0b\x32 .prodvana.version.SourceMetadataJ\x04\x08\x07\x10\x08R\x05\x61\x63tor\"\xb8\x02\n\x0eRelatedObjects\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x05 \x01(\t\x12\x12\n\nrelease_id\x18\x08 \x01(\t\x12\x12\n\nruntime_id\x18\x06 \x01(\t\x12H\n\rexternal_logs\x18\x07 \x03(\x0b\x32\x31.prodvana.events.RelatedObjects.ExternalLogsEntry\x1a\x33\n\x11\x45xternalLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42KZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.events.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/events'
  _RELATEDOBJECTS_EXTERNALLOGSENTRY._options = None
  _RELATEDOBJECTS_EXTERNALLOGSENTRY._serialized_options = b'8\001'
  _globals['_EVENT']._serialized_start=152
  _globals['_EVENT']._serialized_end=495
  _globals['_RELATEDOBJECTS']._serialized_start=498
  _globals['_RELATEDOBJECTS']._serialized_end=810
  _globals['_RELATEDOBJECTS_EXTERNALLOGSENTRY']._serialized_start=759
  _globals['_RELATEDOBJECTS_EXTERNALLOGSENTRY']._serialized_end=810
# @@protoc_insertion_point(module_scope)
