# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/organization/organization_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from prodvana.proto.prodvana.config_writeback import writeback_pb2 as prodvana_dot_config__writeback_dot_writeback__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.organization import user_metadata_pb2 as prodvana_dot_organization_dot_user__metadata__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0prodvana/organization/organization_manager.proto\x12\x15prodvana.organization\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a)prodvana/config_writeback/writeback.proto\x1a prodvana/insights/insights.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a)prodvana/organization/user_metadata.proto\x1a\x1aprodvana/users/users.proto\x1a\x17validate/validate.proto\"\xe8\x01\n\x10OrganizationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12H\n\x10writeback_config\x18\x03 \x01(\x0b\x32..prodvana.config_writeback.ConfigWritebackPath\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x46\n\ruser_metadata\x18\x05 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\x12\x12\n\nui_address\x18\x06 \x01(\t\"\x14\n\x12GetOrganizationReq\"T\n\x13GetOrganizationResp\x12=\n\x0corganization\x18\x01 \x01(\x0b\x32\'.prodvana.organization.OrganizationInfo\"\x83\x01\n\x19GetOrganizationMetricsReq\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"]\n\x1aGetOrganizationMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\"\x1c\n\x1aGetOrganizationInsightsReq\"K\n\x1bGetOrganizationInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\x8a\x01\n\x1cSnoozeOrganizationInsightReq\x12\x31\n\x05\x63lass\x18\x01 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1f\n\x1dSnoozeOrganizationInsightResp\"\x1c\n\x1aGetOrganizationMetadataReq\"`\n\x1bGetOrganizationMetadataResp\x12\x41\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\"i\n\x1aSetOrganizationMetadataReq\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1d\n\x1bSetOrganizationMetadataResp\"&\n\nGetUserReq\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"1\n\x0bGetUserResp\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.prodvana.users.User\"6\n$GetOrganizationSubscriptionStatusReq\x12\x0e\n\x06org_id\x18\x01 \x01(\t\"\x7f\n%GetOrganizationSubscriptionStatusResp\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05trial\x18\x02 \x01(\x08\x12\x37\n\x13trial_end_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"5\n\x14OrganizationSettings\x12\x1d\n\x15\x65nable_ai_integration\x18\x01 \x01(\x08\"V\n\x19OrganizationSettingsDelta\x12\x39\n\x15\x65nable_ai_integration\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x1c\n\x1aGetOrganizationSettingsReq\"\\\n\x1bGetOrganizationSettingsResp\x12=\n\x08settings\x18\x01 \x01(\x0b\x32+.prodvana.organization.OrganizationSettings\"j\n\x1aSetOrganizationSettingsReq\x12L\n\x08settings\x18\x01 \x01(\x0b\x32\x30.prodvana.organization.OrganizationSettingsDeltaB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1d\n\x1bSetOrganizationSettingsResp2\xff\x0c\n\x13OrganizationManager\x12\x82\x01\n\x0fGetOrganization\x12).prodvana.organization.GetOrganizationReq\x1a*.prodvana.organization.GetOrganizationResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/organization\x12\x9f\x01\n\x16GetOrganizationMetrics\x12\x30.prodvana.organization.GetOrganizationMetricsReq\x1a\x31.prodvana.organization.GetOrganizationMetricsResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/organization/metrics\x12\xa3\x01\n\x17GetOrganizationInsights\x12\x31.prodvana.organization.GetOrganizationInsightsReq\x1a\x32.prodvana.organization.GetOrganizationInsightsResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/insights\x12\xb0\x01\n\x19SnoozeOrganizationInsight\x12\x33.prodvana.organization.SnoozeOrganizationInsightReq\x1a\x34.prodvana.organization.SnoozeOrganizationInsightResp\"(\x82\xd3\xe4\x93\x02\"\x1a /v1/organization/insights/snooze\x12\xa3\x01\n\x17GetOrganizationMetadata\x12\x31.prodvana.organization.GetOrganizationMetadataReq\x1a\x32.prodvana.organization.GetOrganizationMetadataResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/metadata\x12\xa6\x01\n\x17SetOrganizationMetadata\x12\x31.prodvana.organization.SetOrganizationMetadataReq\x1a\x32.prodvana.organization.SetOrganizationMetadataResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/organization/metadata:\x01*\x12{\n\x07GetUser\x12!.prodvana.organization.GetUserReq\x1a\".prodvana.organization.GetUserResp\")\x82\xd3\xe4\x93\x02#\x12!/v1/organization/user/{user_id=*}\x12\xcc\x01\n!GetOrganizationSubscriptionStatus\x12;.prodvana.organization.GetOrganizationSubscriptionStatusReq\x1a<.prodvana.organization.GetOrganizationSubscriptionStatusResp\",\x82\xd3\xe4\x93\x02&\x12$/v1/organization/subscription/status\x12\xa3\x01\n\x17GetOrganizationSettings\x12\x31.prodvana.organization.GetOrganizationSettingsReq\x1a\x32.prodvana.organization.GetOrganizationSettingsResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/settings\x12\xa6\x01\n\x17SetOrganizationSettings\x12\x31.prodvana.organization.SetOrganizationSettingsReq\x1a\x32.prodvana.organization.SetOrganizationSettingsResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/organization/settings:\x01*BQZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.organization.organization_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organization'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._options = None
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETUSERREQ.fields_by_name['user_id']._options = None
  _GETUSERREQ.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETORGANIZATIONSETTINGSREQ.fields_by_name['settings']._options = None
  _SETORGANIZATIONSETTINGSREQ.fields_by_name['settings']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/organization'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/organization/metrics'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/insights'
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._serialized_options = b'\202\323\344\223\002\"\032 /v1/organization/insights/snooze'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/metadata'
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/organization/metadata:\001*'
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002#\022!/v1/organization/user/{user_id=*}'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSubscriptionStatus']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSubscriptionStatus']._serialized_options = b'\202\323\344\223\002&\022$/v1/organization/subscription/status'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSettings']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSettings']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/settings'
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationSettings']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationSettings']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/organization/settings:\001*'
  _globals['_ORGANIZATIONINFO']._serialized_start=408
  _globals['_ORGANIZATIONINFO']._serialized_end=640
  _globals['_GETORGANIZATIONREQ']._serialized_start=642
  _globals['_GETORGANIZATIONREQ']._serialized_end=662
  _globals['_GETORGANIZATIONRESP']._serialized_start=664
  _globals['_GETORGANIZATIONRESP']._serialized_end=748
  _globals['_GETORGANIZATIONMETRICSREQ']._serialized_start=751
  _globals['_GETORGANIZATIONMETRICSREQ']._serialized_end=882
  _globals['_GETORGANIZATIONMETRICSRESP']._serialized_start=884
  _globals['_GETORGANIZATIONMETRICSRESP']._serialized_end=977
  _globals['_GETORGANIZATIONINSIGHTSREQ']._serialized_start=979
  _globals['_GETORGANIZATIONINSIGHTSREQ']._serialized_end=1007
  _globals['_GETORGANIZATIONINSIGHTSRESP']._serialized_start=1009
  _globals['_GETORGANIZATIONINSIGHTSRESP']._serialized_end=1084
  _globals['_SNOOZEORGANIZATIONINSIGHTREQ']._serialized_start=1087
  _globals['_SNOOZEORGANIZATIONINSIGHTREQ']._serialized_end=1225
  _globals['_SNOOZEORGANIZATIONINSIGHTRESP']._serialized_start=1227
  _globals['_SNOOZEORGANIZATIONINSIGHTRESP']._serialized_end=1258
  _globals['_GETORGANIZATIONMETADATAREQ']._serialized_start=1260
  _globals['_GETORGANIZATIONMETADATAREQ']._serialized_end=1288
  _globals['_GETORGANIZATIONMETADATARESP']._serialized_start=1290
  _globals['_GETORGANIZATIONMETADATARESP']._serialized_end=1386
  _globals['_SETORGANIZATIONMETADATAREQ']._serialized_start=1388
  _globals['_SETORGANIZATIONMETADATAREQ']._serialized_end=1493
  _globals['_SETORGANIZATIONMETADATARESP']._serialized_start=1495
  _globals['_SETORGANIZATIONMETADATARESP']._serialized_end=1524
  _globals['_GETUSERREQ']._serialized_start=1526
  _globals['_GETUSERREQ']._serialized_end=1564
  _globals['_GETUSERRESP']._serialized_start=1566
  _globals['_GETUSERRESP']._serialized_end=1615
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSREQ']._serialized_start=1617
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSREQ']._serialized_end=1671
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSRESP']._serialized_start=1673
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSRESP']._serialized_end=1800
  _globals['_ORGANIZATIONSETTINGS']._serialized_start=1802
  _globals['_ORGANIZATIONSETTINGS']._serialized_end=1855
  _globals['_ORGANIZATIONSETTINGSDELTA']._serialized_start=1857
  _globals['_ORGANIZATIONSETTINGSDELTA']._serialized_end=1943
  _globals['_GETORGANIZATIONSETTINGSREQ']._serialized_start=1945
  _globals['_GETORGANIZATIONSETTINGSREQ']._serialized_end=1973
  _globals['_GETORGANIZATIONSETTINGSRESP']._serialized_start=1975
  _globals['_GETORGANIZATIONSETTINGSRESP']._serialized_end=2067
  _globals['_SETORGANIZATIONSETTINGSREQ']._serialized_start=2069
  _globals['_SETORGANIZATIONSETTINGSREQ']._serialized_end=2175
  _globals['_SETORGANIZATIONSETTINGSRESP']._serialized_start=2177
  _globals['_SETORGANIZATIONSETTINGSRESP']._serialized_end=2206
  _globals['_ORGANIZATIONMANAGER']._serialized_start=2209
  _globals['_ORGANIZATIONMANAGER']._serialized_end=3872
# @@protoc_insertion_point(module_scope)
