# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/debug/debug.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/desired_state/debug/debug.proto\x12\x1cprodvana.desired_state.debug\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x07\n\x0f\x45ntityDumpState\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x41\n\x1dlast_manager_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0b\x61nnotations\x18\x03 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x41\n\rsimple_status\x18\x0b \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12;\n\x07\x63ontrol\x18\x05 \x01(\x0b\x32*.prodvana.desired_state.model.ControlState\x12G\n\x08io_state\x18\x06 \x01(\x0b\x32\x35.prodvana.desired_state.debug.EntityDumpState.IOState\x12\x34\n\x04logs\x18\x07 \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\x12+\n\rdesired_state\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\x12+\n\rfetched_state\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\x12*\n\x0ctarget_state\x18\x0c \x01(\x0b\x32\x14.google.protobuf.Any\x12N\n\x0c\x63hild_states\x18\n \x03(\x0b\x32\x38.prodvana.desired_state.debug.EntityDumpState.ChildState\x1a\x81\x01\n\x07IOState\x12:\n\x16last_fetched_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_applied_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1ax\n\nChildState\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.prodvana.desired_state.model.Status\"L\n\tDumpState\x12?\n\x08\x65ntities\x18\x01 \x03(\x0b\x32-.prodvana.desired_state.debug.EntityDumpStateBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/debugb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.debug.debug_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/debug'
  _globals['_ENTITYDUMPSTATE']._serialized_start=185
  _globals['_ENTITYDUMPSTATE']._serialized_end=1164
  _globals['_ENTITYDUMPSTATE_IOSTATE']._serialized_start=913
  _globals['_ENTITYDUMPSTATE_IOSTATE']._serialized_end=1042
  _globals['_ENTITYDUMPSTATE_CHILDSTATE']._serialized_start=1044
  _globals['_ENTITYDUMPSTATE_CHILDSTATE']._serialized_end=1164
  _globals['_DUMPSTATE']._serialized_start=1166
  _globals['_DUMPSTATE']._serialized_end=1242
# @@protoc_insertion_point(module_scope)
