# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.deployment import manager_pb2 as prodvana_dot_deployment_dot_manager__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/release/manager.proto\x12\x10prodvana.release\x1a\x1cgoogle/api/annotations.proto\x1a!prodvana/deployment/manager.proto2\xe5\x08\n\x0eReleaseManager\x12}\n\rRecordRelease\x12(.prodvana.deployment.RecordDeploymentReq\x1a).prodvana.deployment.RecordDeploymentResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/releases:\x01*\x12\xa8\x01\n\x13UpdateReleaseStatus\x12..prodvana.deployment.UpdateDeploymentStatusReq\x1a/.prodvana.deployment.UpdateDeploymentStatusResp\"0\x82\xd3\xe4\x93\x02*\"%/v1/releases/{deployment_id=*}/status:\x01*\x12w\n\x0cListReleases\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/releases\x12k\n\x12ListReleasesStream\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x00\x30\x01\x12\x88\x01\n\x0e\x43ompareRelease\x12).prodvana.deployment.CompareDeploymentReq\x1a*.prodvana.deployment.CompareDeploymentResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/compare:\x01*\x12\x88\x01\n\x0ePreviewRelease\x12).prodvana.deployment.PreviewDeploymentReq\x1a*.prodvana.deployment.PreviewDeploymentResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/preview:\x01*\x12\x8d\x01\n\x11GetLatestReleases\x12,.prodvana.deployment.GetLatestDeploymentsReq\x1a-.prodvana.deployment.GetLatestDeploymentsResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/releases/latest\x12\x9c\x01\n\x14\x43heckCommitInRelease\x12/.prodvana.deployment.CheckCommitInDeploymentReq\x1a\x30.prodvana.deployment.CheckCommitInDeploymentResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/releases/check_commitBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RELEASEMANAGER.methods_by_name['RecordRelease']._options = None
  _RELEASEMANAGER.methods_by_name['RecordRelease']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/releases:\001*'
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._options = None
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._serialized_options = b'\202\323\344\223\002*\"%/v1/releases/{deployment_id=*}/status:\001*'
  _RELEASEMANAGER.methods_by_name['ListReleases']._options = None
  _RELEASEMANAGER.methods_by_name['ListReleases']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/releases'
  _RELEASEMANAGER.methods_by_name['CompareRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CompareRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/compare:\001*'
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._options = None
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/preview:\001*'
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._options = None
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/releases/latest'
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/releases/check_commit'
  _globals['_RELEASEMANAGER']._serialized_start=118
  _globals['_RELEASEMANAGER']._serialized_end=1243
# @@protoc_insertion_point(module_scope)
