# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/async_task/task_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/async_task/task_metadata.proto\x12\x13prodvana.async_task\"\x19\n\nTaskResult\x12\x0b\n\x03log\x18\x01 \x01(\x0c*L\n\nTaskStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/async_taskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.async_task.task_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/async_task'
  _globals['_TASKSTATUS']._serialized_start=91
  _globals['_TASKSTATUS']._serialized_end=167
  _globals['_TASKRESULT']._serialized_start=64
  _globals['_TASKRESULT']._serialized_end=89
# @@protoc_insertion_point(module_scope)
